# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = ['ConsumerOauth2Args', 'ConsumerOauth2']

@pulumi.input_type
class ConsumerOauth2Args:
    def __init__(__self__, *,
                 consumer_id: pulumi.Input[builtins.str],
                 redirect_uris: pulumi.Input[Sequence[pulumi.Input[builtins.str]]],
                 client_id: Optional[pulumi.Input[builtins.str]] = None,
                 client_secret: Optional[pulumi.Input[builtins.str]] = None,
                 hash_secret: Optional[pulumi.Input[builtins.bool]] = None,
                 name: Optional[pulumi.Input[builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None):
        """
        The set of arguments for constructing a ConsumerOauth2 resource.
        :param pulumi.Input[builtins.str] consumer_id: The id of the consumer to be configured with oauth2.
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] redirect_uris: An array with one or more URLs in your app where users will be sent after authorization ([RFC 6742 Section 3.1.2](https://tools.ietf.org/html/rfc6749#section-3.1.2)).
        :param pulumi.Input[builtins.str] client_id: Unique oauth2 client id. If not set, the oauth2 plugin will generate one
        :param pulumi.Input[builtins.str] client_secret: Unique oauth2 client secret. If not set, the oauth2 plugin will generate one
        :param pulumi.Input[builtins.bool] hash_secret: A boolean flag that indicates whether the client_secret field will be stored in hashed form. If enabled on existing plugin instances, client secrets are hashed on the fly upon first usage. Default: `false`.
        :param pulumi.Input[builtins.str] name: The name associated with the credential.
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] tags: A list of strings associated with the consumer for grouping and filtering.
        """
        pulumi.set(__self__, "consumer_id", consumer_id)
        pulumi.set(__self__, "redirect_uris", redirect_uris)
        if client_id is not None:
            pulumi.set(__self__, "client_id", client_id)
        if client_secret is not None:
            pulumi.set(__self__, "client_secret", client_secret)
        if hash_secret is not None:
            pulumi.set(__self__, "hash_secret", hash_secret)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)

    @property
    @pulumi.getter(name="consumerId")
    def consumer_id(self) -> pulumi.Input[builtins.str]:
        """
        The id of the consumer to be configured with oauth2.
        """
        return pulumi.get(self, "consumer_id")

    @consumer_id.setter
    def consumer_id(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "consumer_id", value)

    @property
    @pulumi.getter(name="redirectUris")
    def redirect_uris(self) -> pulumi.Input[Sequence[pulumi.Input[builtins.str]]]:
        """
        An array with one or more URLs in your app where users will be sent after authorization ([RFC 6742 Section 3.1.2](https://tools.ietf.org/html/rfc6749#section-3.1.2)).
        """
        return pulumi.get(self, "redirect_uris")

    @redirect_uris.setter
    def redirect_uris(self, value: pulumi.Input[Sequence[pulumi.Input[builtins.str]]]):
        pulumi.set(self, "redirect_uris", value)

    @property
    @pulumi.getter(name="clientId")
    def client_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Unique oauth2 client id. If not set, the oauth2 plugin will generate one
        """
        return pulumi.get(self, "client_id")

    @client_id.setter
    def client_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "client_id", value)

    @property
    @pulumi.getter(name="clientSecret")
    def client_secret(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Unique oauth2 client secret. If not set, the oauth2 plugin will generate one
        """
        return pulumi.get(self, "client_secret")

    @client_secret.setter
    def client_secret(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "client_secret", value)

    @property
    @pulumi.getter(name="hashSecret")
    def hash_secret(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        A boolean flag that indicates whether the client_secret field will be stored in hashed form. If enabled on existing plugin instances, client secrets are hashed on the fly upon first usage. Default: `false`.
        """
        return pulumi.get(self, "hash_secret")

    @hash_secret.setter
    def hash_secret(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "hash_secret", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The name associated with the credential.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]:
        """
        A list of strings associated with the consumer for grouping and filtering.
        """
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "tags", value)


@pulumi.input_type
class _ConsumerOauth2State:
    def __init__(__self__, *,
                 client_id: Optional[pulumi.Input[builtins.str]] = None,
                 client_secret: Optional[pulumi.Input[builtins.str]] = None,
                 consumer_id: Optional[pulumi.Input[builtins.str]] = None,
                 hash_secret: Optional[pulumi.Input[builtins.bool]] = None,
                 name: Optional[pulumi.Input[builtins.str]] = None,
                 redirect_uris: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None):
        """
        Input properties used for looking up and filtering ConsumerOauth2 resources.
        :param pulumi.Input[builtins.str] client_id: Unique oauth2 client id. If not set, the oauth2 plugin will generate one
        :param pulumi.Input[builtins.str] client_secret: Unique oauth2 client secret. If not set, the oauth2 plugin will generate one
        :param pulumi.Input[builtins.str] consumer_id: The id of the consumer to be configured with oauth2.
        :param pulumi.Input[builtins.bool] hash_secret: A boolean flag that indicates whether the client_secret field will be stored in hashed form. If enabled on existing plugin instances, client secrets are hashed on the fly upon first usage. Default: `false`.
        :param pulumi.Input[builtins.str] name: The name associated with the credential.
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] redirect_uris: An array with one or more URLs in your app where users will be sent after authorization ([RFC 6742 Section 3.1.2](https://tools.ietf.org/html/rfc6749#section-3.1.2)).
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] tags: A list of strings associated with the consumer for grouping and filtering.
        """
        if client_id is not None:
            pulumi.set(__self__, "client_id", client_id)
        if client_secret is not None:
            pulumi.set(__self__, "client_secret", client_secret)
        if consumer_id is not None:
            pulumi.set(__self__, "consumer_id", consumer_id)
        if hash_secret is not None:
            pulumi.set(__self__, "hash_secret", hash_secret)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if redirect_uris is not None:
            pulumi.set(__self__, "redirect_uris", redirect_uris)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)

    @property
    @pulumi.getter(name="clientId")
    def client_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Unique oauth2 client id. If not set, the oauth2 plugin will generate one
        """
        return pulumi.get(self, "client_id")

    @client_id.setter
    def client_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "client_id", value)

    @property
    @pulumi.getter(name="clientSecret")
    def client_secret(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Unique oauth2 client secret. If not set, the oauth2 plugin will generate one
        """
        return pulumi.get(self, "client_secret")

    @client_secret.setter
    def client_secret(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "client_secret", value)

    @property
    @pulumi.getter(name="consumerId")
    def consumer_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The id of the consumer to be configured with oauth2.
        """
        return pulumi.get(self, "consumer_id")

    @consumer_id.setter
    def consumer_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "consumer_id", value)

    @property
    @pulumi.getter(name="hashSecret")
    def hash_secret(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        A boolean flag that indicates whether the client_secret field will be stored in hashed form. If enabled on existing plugin instances, client secrets are hashed on the fly upon first usage. Default: `false`.
        """
        return pulumi.get(self, "hash_secret")

    @hash_secret.setter
    def hash_secret(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "hash_secret", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The name associated with the credential.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter(name="redirectUris")
    def redirect_uris(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]:
        """
        An array with one or more URLs in your app where users will be sent after authorization ([RFC 6742 Section 3.1.2](https://tools.ietf.org/html/rfc6749#section-3.1.2)).
        """
        return pulumi.get(self, "redirect_uris")

    @redirect_uris.setter
    def redirect_uris(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "redirect_uris", value)

    @property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]:
        """
        A list of strings associated with the consumer for grouping and filtering.
        """
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "tags", value)


@pulumi.type_token("kong:index/consumerOauth2:ConsumerOauth2")
class ConsumerOauth2(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 client_id: Optional[pulumi.Input[builtins.str]] = None,
                 client_secret: Optional[pulumi.Input[builtins.str]] = None,
                 consumer_id: Optional[pulumi.Input[builtins.str]] = None,
                 hash_secret: Optional[pulumi.Input[builtins.bool]] = None,
                 name: Optional[pulumi.Input[builtins.str]] = None,
                 redirect_uris: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 __props__=None):
        """
        ## # ConsumerOauth2

        Resource that allows you to configure the OAuth2 plugin credentials for a consumer.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_kong as kong

        my_consumer = kong.Consumer("my_consumer",
            username="User1",
            custom_id="123")
        oauth2_plugin = kong.Plugin("oauth2_plugin",
            name="oauth2",
            config_json=\"\"\"\\x09{
        \\x09\\x09"global_credentials": true,
        \\x09\\x09"enable_password_grant": true,
        \\x09\\x09"token_expiration": 180,
        \\x09\\x09"refresh_token_ttl": 180,
        \\x09\\x09"provision_key": "testprovisionkey"
        \\x09}
        \"\"\")
        consumer_oauth2 = kong.ConsumerOauth2("consumer_oauth2",
            name="test_application",
            consumer_id=my_consumer.id,
            client_id="client_id",
            client_secret="client_secret",
            redirect_uris=[
                "https://asdf.com/callback",
                "https://test.cl/callback",
            ],
            tags=["myTag"])
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] client_id: Unique oauth2 client id. If not set, the oauth2 plugin will generate one
        :param pulumi.Input[builtins.str] client_secret: Unique oauth2 client secret. If not set, the oauth2 plugin will generate one
        :param pulumi.Input[builtins.str] consumer_id: The id of the consumer to be configured with oauth2.
        :param pulumi.Input[builtins.bool] hash_secret: A boolean flag that indicates whether the client_secret field will be stored in hashed form. If enabled on existing plugin instances, client secrets are hashed on the fly upon first usage. Default: `false`.
        :param pulumi.Input[builtins.str] name: The name associated with the credential.
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] redirect_uris: An array with one or more URLs in your app where users will be sent after authorization ([RFC 6742 Section 3.1.2](https://tools.ietf.org/html/rfc6749#section-3.1.2)).
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] tags: A list of strings associated with the consumer for grouping and filtering.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: ConsumerOauth2Args,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        ## # ConsumerOauth2

        Resource that allows you to configure the OAuth2 plugin credentials for a consumer.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_kong as kong

        my_consumer = kong.Consumer("my_consumer",
            username="User1",
            custom_id="123")
        oauth2_plugin = kong.Plugin("oauth2_plugin",
            name="oauth2",
            config_json=\"\"\"\\x09{
        \\x09\\x09"global_credentials": true,
        \\x09\\x09"enable_password_grant": true,
        \\x09\\x09"token_expiration": 180,
        \\x09\\x09"refresh_token_ttl": 180,
        \\x09\\x09"provision_key": "testprovisionkey"
        \\x09}
        \"\"\")
        consumer_oauth2 = kong.ConsumerOauth2("consumer_oauth2",
            name="test_application",
            consumer_id=my_consumer.id,
            client_id="client_id",
            client_secret="client_secret",
            redirect_uris=[
                "https://asdf.com/callback",
                "https://test.cl/callback",
            ],
            tags=["myTag"])
        ```

        :param str resource_name: The name of the resource.
        :param ConsumerOauth2Args args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(ConsumerOauth2Args, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 client_id: Optional[pulumi.Input[builtins.str]] = None,
                 client_secret: Optional[pulumi.Input[builtins.str]] = None,
                 consumer_id: Optional[pulumi.Input[builtins.str]] = None,
                 hash_secret: Optional[pulumi.Input[builtins.bool]] = None,
                 name: Optional[pulumi.Input[builtins.str]] = None,
                 redirect_uris: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = ConsumerOauth2Args.__new__(ConsumerOauth2Args)

            __props__.__dict__["client_id"] = client_id
            __props__.__dict__["client_secret"] = client_secret
            if consumer_id is None and not opts.urn:
                raise TypeError("Missing required property 'consumer_id'")
            __props__.__dict__["consumer_id"] = consumer_id
            __props__.__dict__["hash_secret"] = hash_secret
            __props__.__dict__["name"] = name
            if redirect_uris is None and not opts.urn:
                raise TypeError("Missing required property 'redirect_uris'")
            __props__.__dict__["redirect_uris"] = redirect_uris
            __props__.__dict__["tags"] = tags
        super(ConsumerOauth2, __self__).__init__(
            'kong:index/consumerOauth2:ConsumerOauth2',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            client_id: Optional[pulumi.Input[builtins.str]] = None,
            client_secret: Optional[pulumi.Input[builtins.str]] = None,
            consumer_id: Optional[pulumi.Input[builtins.str]] = None,
            hash_secret: Optional[pulumi.Input[builtins.bool]] = None,
            name: Optional[pulumi.Input[builtins.str]] = None,
            redirect_uris: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
            tags: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None) -> 'ConsumerOauth2':
        """
        Get an existing ConsumerOauth2 resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] client_id: Unique oauth2 client id. If not set, the oauth2 plugin will generate one
        :param pulumi.Input[builtins.str] client_secret: Unique oauth2 client secret. If not set, the oauth2 plugin will generate one
        :param pulumi.Input[builtins.str] consumer_id: The id of the consumer to be configured with oauth2.
        :param pulumi.Input[builtins.bool] hash_secret: A boolean flag that indicates whether the client_secret field will be stored in hashed form. If enabled on existing plugin instances, client secrets are hashed on the fly upon first usage. Default: `false`.
        :param pulumi.Input[builtins.str] name: The name associated with the credential.
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] redirect_uris: An array with one or more URLs in your app where users will be sent after authorization ([RFC 6742 Section 3.1.2](https://tools.ietf.org/html/rfc6749#section-3.1.2)).
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] tags: A list of strings associated with the consumer for grouping and filtering.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _ConsumerOauth2State.__new__(_ConsumerOauth2State)

        __props__.__dict__["client_id"] = client_id
        __props__.__dict__["client_secret"] = client_secret
        __props__.__dict__["consumer_id"] = consumer_id
        __props__.__dict__["hash_secret"] = hash_secret
        __props__.__dict__["name"] = name
        __props__.__dict__["redirect_uris"] = redirect_uris
        __props__.__dict__["tags"] = tags
        return ConsumerOauth2(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="clientId")
    def client_id(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        Unique oauth2 client id. If not set, the oauth2 plugin will generate one
        """
        return pulumi.get(self, "client_id")

    @property
    @pulumi.getter(name="clientSecret")
    def client_secret(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        Unique oauth2 client secret. If not set, the oauth2 plugin will generate one
        """
        return pulumi.get(self, "client_secret")

    @property
    @pulumi.getter(name="consumerId")
    def consumer_id(self) -> pulumi.Output[builtins.str]:
        """
        The id of the consumer to be configured with oauth2.
        """
        return pulumi.get(self, "consumer_id")

    @property
    @pulumi.getter(name="hashSecret")
    def hash_secret(self) -> pulumi.Output[Optional[builtins.bool]]:
        """
        A boolean flag that indicates whether the client_secret field will be stored in hashed form. If enabled on existing plugin instances, client secrets are hashed on the fly upon first usage. Default: `false`.
        """
        return pulumi.get(self, "hash_secret")

    @property
    @pulumi.getter
    def name(self) -> pulumi.Output[builtins.str]:
        """
        The name associated with the credential.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="redirectUris")
    def redirect_uris(self) -> pulumi.Output[Sequence[builtins.str]]:
        """
        An array with one or more URLs in your app where users will be sent after authorization ([RFC 6742 Section 3.1.2](https://tools.ietf.org/html/rfc6749#section-3.1.2)).
        """
        return pulumi.get(self, "redirect_uris")

    @property
    @pulumi.getter
    def tags(self) -> pulumi.Output[Optional[Sequence[builtins.str]]]:
        """
        A list of strings associated with the consumer for grouping and filtering.
        """
        return pulumi.get(self, "tags")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = ['ConsumerArgs', 'Consumer']

@pulumi.input_type
class ConsumerArgs:
    def __init__(__self__, *,
                 custom_id: Optional[pulumi.Input[builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 username: Optional[pulumi.Input[builtins.str]] = None):
        """
        The set of arguments for constructing a Consumer resource.
        :param pulumi.Input[builtins.str] custom_id: A custom id for the consumer, you must set either the username or custom_id
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] tags: A list of strings associated with the Consumer for grouping and filtering
        :param pulumi.Input[builtins.str] username: The username to use, you must set either the username or custom_id
        """
        if custom_id is not None:
            pulumi.set(__self__, "custom_id", custom_id)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)
        if username is not None:
            pulumi.set(__self__, "username", username)

    @property
    @pulumi.getter(name="customId")
    def custom_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        A custom id for the consumer, you must set either the username or custom_id
        """
        return pulumi.get(self, "custom_id")

    @custom_id.setter
    def custom_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "custom_id", value)

    @property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]:
        """
        A list of strings associated with the Consumer for grouping and filtering
        """
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "tags", value)

    @property
    @pulumi.getter
    def username(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The username to use, you must set either the username or custom_id
        """
        return pulumi.get(self, "username")

    @username.setter
    def username(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "username", value)


@pulumi.input_type
class _ConsumerState:
    def __init__(__self__, *,
                 custom_id: Optional[pulumi.Input[builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 username: Optional[pulumi.Input[builtins.str]] = None):
        """
        Input properties used for looking up and filtering Consumer resources.
        :param pulumi.Input[builtins.str] custom_id: A custom id for the consumer, you must set either the username or custom_id
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] tags: A list of strings associated with the Consumer for grouping and filtering
        :param pulumi.Input[builtins.str] username: The username to use, you must set either the username or custom_id
        """
        if custom_id is not None:
            pulumi.set(__self__, "custom_id", custom_id)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)
        if username is not None:
            pulumi.set(__self__, "username", username)

    @property
    @pulumi.getter(name="customId")
    def custom_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        A custom id for the consumer, you must set either the username or custom_id
        """
        return pulumi.get(self, "custom_id")

    @custom_id.setter
    def custom_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "custom_id", value)

    @property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]:
        """
        A list of strings associated with the Consumer for grouping and filtering
        """
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "tags", value)

    @property
    @pulumi.getter
    def username(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The username to use, you must set either the username or custom_id
        """
        return pulumi.get(self, "username")

    @username.setter
    def username(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "username", value)


@pulumi.type_token("kong:index/consumer:Consumer")
class Consumer(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 custom_id: Optional[pulumi.Input[builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 username: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        """
        ## # Consumer

        The consumer resource maps directly onto the json for creating a Consumer in Kong.  For more information on the parameters [see the Kong Consumer create documentation](https://docs.konghq.com/gateway-oss/2.5.x/admin-api/#consumer-object).

        ## Example Usage

        ```python
        import pulumi
        import pulumi_kong as kong

        consumer = kong.Consumer("consumer",
            username="User1",
            custom_id="123",
            tags=["mySuperTag"])
        ```

        ## Import

        To import a consumer:

        ```sh
        $ pulumi import kong:index/consumer:Consumer <consumer_identifier> <consumer_id>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] custom_id: A custom id for the consumer, you must set either the username or custom_id
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] tags: A list of strings associated with the Consumer for grouping and filtering
        :param pulumi.Input[builtins.str] username: The username to use, you must set either the username or custom_id
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: Optional[ConsumerArgs] = None,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        ## # Consumer

        The consumer resource maps directly onto the json for creating a Consumer in Kong.  For more information on the parameters [see the Kong Consumer create documentation](https://docs.konghq.com/gateway-oss/2.5.x/admin-api/#consumer-object).

        ## Example Usage

        ```python
        import pulumi
        import pulumi_kong as kong

        consumer = kong.Consumer("consumer",
            username="User1",
            custom_id="123",
            tags=["mySuperTag"])
        ```

        ## Import

        To import a consumer:

        ```sh
        $ pulumi import kong:index/consumer:Consumer <consumer_identifier> <consumer_id>
        ```

        :param str resource_name: The name of the resource.
        :param ConsumerArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(ConsumerArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 custom_id: Optional[pulumi.Input[builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 username: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = ConsumerArgs.__new__(ConsumerArgs)

            __props__.__dict__["custom_id"] = custom_id
            __props__.__dict__["tags"] = tags
            __props__.__dict__["username"] = username
        super(Consumer, __self__).__init__(
            'kong:index/consumer:Consumer',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            custom_id: Optional[pulumi.Input[builtins.str]] = None,
            tags: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
            username: Optional[pulumi.Input[builtins.str]] = None) -> 'Consumer':
        """
        Get an existing Consumer resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] custom_id: A custom id for the consumer, you must set either the username or custom_id
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] tags: A list of strings associated with the Consumer for grouping and filtering
        :param pulumi.Input[builtins.str] username: The username to use, you must set either the username or custom_id
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _ConsumerState.__new__(_ConsumerState)

        __props__.__dict__["custom_id"] = custom_id
        __props__.__dict__["tags"] = tags
        __props__.__dict__["username"] = username
        return Consumer(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="customId")
    def custom_id(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        A custom id for the consumer, you must set either the username or custom_id
        """
        return pulumi.get(self, "custom_id")

    @property
    @pulumi.getter
    def tags(self) -> pulumi.Output[Optional[Sequence[builtins.str]]]:
        """
        A list of strings associated with the Consumer for grouping and filtering
        """
        return pulumi.get(self, "tags")

    @property
    @pulumi.getter
    def username(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        The username to use, you must set either the username or custom_id
        """
        return pulumi.get(self, "username")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = ['TargetArgs', 'Target']

@pulumi.input_type
class TargetArgs:
    def __init__(__self__, *,
                 target: pulumi.Input[builtins.str],
                 upstream_id: pulumi.Input[builtins.str],
                 weight: pulumi.Input[builtins.int],
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None):
        """
        The set of arguments for constructing a Target resource.
        :param pulumi.Input[builtins.str] target: is the target address (IP or hostname) and port. If omitted the port defaults to 8000.
        :param pulumi.Input[builtins.str] upstream_id: is the id of the upstream to apply this target to.
        :param pulumi.Input[builtins.int] weight: is the weight this target gets within the upstream load balancer (0-1000, defaults to 100).
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] tags: A list set of strings associated with the Plugin for grouping and filtering
        """
        pulumi.set(__self__, "target", target)
        pulumi.set(__self__, "upstream_id", upstream_id)
        pulumi.set(__self__, "weight", weight)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)

    @property
    @pulumi.getter
    def target(self) -> pulumi.Input[builtins.str]:
        """
        is the target address (IP or hostname) and port. If omitted the port defaults to 8000.
        """
        return pulumi.get(self, "target")

    @target.setter
    def target(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "target", value)

    @property
    @pulumi.getter(name="upstreamId")
    def upstream_id(self) -> pulumi.Input[builtins.str]:
        """
        is the id of the upstream to apply this target to.
        """
        return pulumi.get(self, "upstream_id")

    @upstream_id.setter
    def upstream_id(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "upstream_id", value)

    @property
    @pulumi.getter
    def weight(self) -> pulumi.Input[builtins.int]:
        """
        is the weight this target gets within the upstream load balancer (0-1000, defaults to 100).
        """
        return pulumi.get(self, "weight")

    @weight.setter
    def weight(self, value: pulumi.Input[builtins.int]):
        pulumi.set(self, "weight", value)

    @property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]:
        """
        A list set of strings associated with the Plugin for grouping and filtering
        """
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "tags", value)


@pulumi.input_type
class _TargetState:
    def __init__(__self__, *,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 target: Optional[pulumi.Input[builtins.str]] = None,
                 upstream_id: Optional[pulumi.Input[builtins.str]] = None,
                 weight: Optional[pulumi.Input[builtins.int]] = None):
        """
        Input properties used for looking up and filtering Target resources.
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] tags: A list set of strings associated with the Plugin for grouping and filtering
        :param pulumi.Input[builtins.str] target: is the target address (IP or hostname) and port. If omitted the port defaults to 8000.
        :param pulumi.Input[builtins.str] upstream_id: is the id of the upstream to apply this target to.
        :param pulumi.Input[builtins.int] weight: is the weight this target gets within the upstream load balancer (0-1000, defaults to 100).
        """
        if tags is not None:
            pulumi.set(__self__, "tags", tags)
        if target is not None:
            pulumi.set(__self__, "target", target)
        if upstream_id is not None:
            pulumi.set(__self__, "upstream_id", upstream_id)
        if weight is not None:
            pulumi.set(__self__, "weight", weight)

    @property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]:
        """
        A list set of strings associated with the Plugin for grouping and filtering
        """
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "tags", value)

    @property
    @pulumi.getter
    def target(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        is the target address (IP or hostname) and port. If omitted the port defaults to 8000.
        """
        return pulumi.get(self, "target")

    @target.setter
    def target(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "target", value)

    @property
    @pulumi.getter(name="upstreamId")
    def upstream_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        is the id of the upstream to apply this target to.
        """
        return pulumi.get(self, "upstream_id")

    @upstream_id.setter
    def upstream_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "upstream_id", value)

    @property
    @pulumi.getter
    def weight(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        is the weight this target gets within the upstream load balancer (0-1000, defaults to 100).
        """
        return pulumi.get(self, "weight")

    @weight.setter
    def weight(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "weight", value)


@pulumi.type_token("kong:index/target:Target")
class Target(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 target: Optional[pulumi.Input[builtins.str]] = None,
                 upstream_id: Optional[pulumi.Input[builtins.str]] = None,
                 weight: Optional[pulumi.Input[builtins.int]] = None,
                 __props__=None):
        """
        ## Example Usage

        ```python
        import pulumi
        import pulumi_kong as kong

        target = kong.Target("target",
            target="sample_target:80",
            weight=10,
            upstream_id=upstream["id"])
        ```

        ## Import

        To import a target use a combination of the upstream id and the target id as follows:

        ```sh
        $ pulumi import kong:index/target:Target <target_identifier> <upstream_id>/<target_id>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] tags: A list set of strings associated with the Plugin for grouping and filtering
        :param pulumi.Input[builtins.str] target: is the target address (IP or hostname) and port. If omitted the port defaults to 8000.
        :param pulumi.Input[builtins.str] upstream_id: is the id of the upstream to apply this target to.
        :param pulumi.Input[builtins.int] weight: is the weight this target gets within the upstream load balancer (0-1000, defaults to 100).
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: TargetArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        ## Example Usage

        ```python
        import pulumi
        import pulumi_kong as kong

        target = kong.Target("target",
            target="sample_target:80",
            weight=10,
            upstream_id=upstream["id"])
        ```

        ## Import

        To import a target use a combination of the upstream id and the target id as follows:

        ```sh
        $ pulumi import kong:index/target:Target <target_identifier> <upstream_id>/<target_id>
        ```

        :param str resource_name: The name of the resource.
        :param TargetArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(TargetArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 target: Optional[pulumi.Input[builtins.str]] = None,
                 upstream_id: Optional[pulumi.Input[builtins.str]] = None,
                 weight: Optional[pulumi.Input[builtins.int]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = TargetArgs.__new__(TargetArgs)

            __props__.__dict__["tags"] = tags
            if target is None and not opts.urn:
                raise TypeError("Missing required property 'target'")
            __props__.__dict__["target"] = target
            if upstream_id is None and not opts.urn:
                raise TypeError("Missing required property 'upstream_id'")
            __props__.__dict__["upstream_id"] = upstream_id
            if weight is None and not opts.urn:
                raise TypeError("Missing required property 'weight'")
            __props__.__dict__["weight"] = weight
        super(Target, __self__).__init__(
            'kong:index/target:Target',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            tags: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
            target: Optional[pulumi.Input[builtins.str]] = None,
            upstream_id: Optional[pulumi.Input[builtins.str]] = None,
            weight: Optional[pulumi.Input[builtins.int]] = None) -> 'Target':
        """
        Get an existing Target resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] tags: A list set of strings associated with the Plugin for grouping and filtering
        :param pulumi.Input[builtins.str] target: is the target address (IP or hostname) and port. If omitted the port defaults to 8000.
        :param pulumi.Input[builtins.str] upstream_id: is the id of the upstream to apply this target to.
        :param pulumi.Input[builtins.int] weight: is the weight this target gets within the upstream load balancer (0-1000, defaults to 100).
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _TargetState.__new__(_TargetState)

        __props__.__dict__["tags"] = tags
        __props__.__dict__["target"] = target
        __props__.__dict__["upstream_id"] = upstream_id
        __props__.__dict__["weight"] = weight
        return Target(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter
    def tags(self) -> pulumi.Output[Optional[Sequence[builtins.str]]]:
        """
        A list set of strings associated with the Plugin for grouping and filtering
        """
        return pulumi.get(self, "tags")

    @property
    @pulumi.getter
    def target(self) -> pulumi.Output[builtins.str]:
        """
        is the target address (IP or hostname) and port. If omitted the port defaults to 8000.
        """
        return pulumi.get(self, "target")

    @property
    @pulumi.getter(name="upstreamId")
    def upstream_id(self) -> pulumi.Output[builtins.str]:
        """
        is the id of the upstream to apply this target to.
        """
        return pulumi.get(self, "upstream_id")

    @property
    @pulumi.getter
    def weight(self) -> pulumi.Output[builtins.int]:
        """
        is the weight this target gets within the upstream load balancer (0-1000, defaults to 100).
        """
        return pulumi.get(self, "weight")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = ['ProviderArgs', 'Provider']

@pulumi.input_type
class ProviderArgs:
    def __init__(__self__, *,
                 kong_admin_password: Optional[pulumi.Input[builtins.str]] = None,
                 kong_admin_token: Optional[pulumi.Input[builtins.str]] = None,
                 kong_admin_uri: Optional[pulumi.Input[builtins.str]] = None,
                 kong_admin_username: Optional[pulumi.Input[builtins.str]] = None,
                 kong_api_key: Optional[pulumi.Input[builtins.str]] = None,
                 kong_workspace: Optional[pulumi.Input[builtins.str]] = None,
                 strict_plugins_match: Optional[pulumi.Input[builtins.bool]] = None,
                 tls_skip_verify: Optional[pulumi.Input[builtins.bool]] = None):
        """
        The set of arguments for constructing a Provider resource.
        :param pulumi.Input[builtins.str] kong_admin_password: An basic auth password for kong admin
        :param pulumi.Input[builtins.str] kong_admin_token: API key for the kong api (Enterprise Edition)
        :param pulumi.Input[builtins.str] kong_admin_uri: The address of the kong admin url e.g. http://localhost:8001
        :param pulumi.Input[builtins.str] kong_admin_username: An basic auth user for kong admin
        :param pulumi.Input[builtins.str] kong_api_key: API key for the kong api (if you have locked it down)
        :param pulumi.Input[builtins.str] kong_workspace: Workspace context (Enterprise Edition)
        :param pulumi.Input[builtins.bool] strict_plugins_match: Should plugins `config_json` field strictly match plugin configuration
        :param pulumi.Input[builtins.bool] tls_skip_verify: Whether to skip tls verify for https kong api endpoint using self signed or untrusted certs
        """
        if kong_admin_password is not None:
            pulumi.set(__self__, "kong_admin_password", kong_admin_password)
        if kong_admin_token is not None:
            pulumi.set(__self__, "kong_admin_token", kong_admin_token)
        if kong_admin_uri is not None:
            pulumi.set(__self__, "kong_admin_uri", kong_admin_uri)
        if kong_admin_username is not None:
            pulumi.set(__self__, "kong_admin_username", kong_admin_username)
        if kong_api_key is not None:
            pulumi.set(__self__, "kong_api_key", kong_api_key)
        if kong_workspace is not None:
            pulumi.set(__self__, "kong_workspace", kong_workspace)
        if strict_plugins_match is None:
            strict_plugins_match = _utilities.get_env_bool('STRICT_PLUGINS_MATCH')
        if strict_plugins_match is not None:
            pulumi.set(__self__, "strict_plugins_match", strict_plugins_match)
        if tls_skip_verify is None:
            tls_skip_verify = (_utilities.get_env_bool('TLS_SKIP_VERIFY') or False)
        if tls_skip_verify is not None:
            pulumi.set(__self__, "tls_skip_verify", tls_skip_verify)

    @property
    @pulumi.getter(name="kongAdminPassword")
    def kong_admin_password(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        An basic auth password for kong admin
        """
        return pulumi.get(self, "kong_admin_password")

    @kong_admin_password.setter
    def kong_admin_password(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "kong_admin_password", value)

    @property
    @pulumi.getter(name="kongAdminToken")
    def kong_admin_token(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        API key for the kong api (Enterprise Edition)
        """
        return pulumi.get(self, "kong_admin_token")

    @kong_admin_token.setter
    def kong_admin_token(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "kong_admin_token", value)

    @property
    @pulumi.getter(name="kongAdminUri")
    def kong_admin_uri(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The address of the kong admin url e.g. http://localhost:8001
        """
        return pulumi.get(self, "kong_admin_uri")

    @kong_admin_uri.setter
    def kong_admin_uri(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "kong_admin_uri", value)

    @property
    @pulumi.getter(name="kongAdminUsername")
    def kong_admin_username(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        An basic auth user for kong admin
        """
        return pulumi.get(self, "kong_admin_username")

    @kong_admin_username.setter
    def kong_admin_username(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "kong_admin_username", value)

    @property
    @pulumi.getter(name="kongApiKey")
    def kong_api_key(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        API key for the kong api (if you have locked it down)
        """
        return pulumi.get(self, "kong_api_key")

    @kong_api_key.setter
    def kong_api_key(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "kong_api_key", value)

    @property
    @pulumi.getter(name="kongWorkspace")
    def kong_workspace(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Workspace context (Enterprise Edition)
        """
        return pulumi.get(self, "kong_workspace")

    @kong_workspace.setter
    def kong_workspace(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "kong_workspace", value)

    @property
    @pulumi.getter(name="strictPluginsMatch")
    def strict_plugins_match(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        Should plugins `config_json` field strictly match plugin configuration
        """
        return pulumi.get(self, "strict_plugins_match")

    @strict_plugins_match.setter
    def strict_plugins_match(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "strict_plugins_match", value)

    @property
    @pulumi.getter(name="tlsSkipVerify")
    def tls_skip_verify(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        Whether to skip tls verify for https kong api endpoint using self signed or untrusted certs
        """
        return pulumi.get(self, "tls_skip_verify")

    @tls_skip_verify.setter
    def tls_skip_verify(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "tls_skip_verify", value)


@pulumi.type_token("pulumi:providers:kong")
class Provider(pulumi.ProviderResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 kong_admin_password: Optional[pulumi.Input[builtins.str]] = None,
                 kong_admin_token: Optional[pulumi.Input[builtins.str]] = None,
                 kong_admin_uri: Optional[pulumi.Input[builtins.str]] = None,
                 kong_admin_username: Optional[pulumi.Input[builtins.str]] = None,
                 kong_api_key: Optional[pulumi.Input[builtins.str]] = None,
                 kong_workspace: Optional[pulumi.Input[builtins.str]] = None,
                 strict_plugins_match: Optional[pulumi.Input[builtins.bool]] = None,
                 tls_skip_verify: Optional[pulumi.Input[builtins.bool]] = None,
                 __props__=None):
        """
        The provider type for the kong package. By default, resources use package-wide configuration
        settings, however an explicit `Provider` instance may be created and passed during resource
        construction to achieve fine-grained programmatic control over provider settings. See the
        [documentation](https://www.pulumi.com/docs/reference/programming-model/#providers) for more information.

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] kong_admin_password: An basic auth password for kong admin
        :param pulumi.Input[builtins.str] kong_admin_token: API key for the kong api (Enterprise Edition)
        :param pulumi.Input[builtins.str] kong_admin_uri: The address of the kong admin url e.g. http://localhost:8001
        :param pulumi.Input[builtins.str] kong_admin_username: An basic auth user for kong admin
        :param pulumi.Input[builtins.str] kong_api_key: API key for the kong api (if you have locked it down)
        :param pulumi.Input[builtins.str] kong_workspace: Workspace context (Enterprise Edition)
        :param pulumi.Input[builtins.bool] strict_plugins_match: Should plugins `config_json` field strictly match plugin configuration
        :param pulumi.Input[builtins.bool] tls_skip_verify: Whether to skip tls verify for https kong api endpoint using self signed or untrusted certs
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: Optional[ProviderArgs] = None,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        The provider type for the kong package. By default, resources use package-wide configuration
        settings, however an explicit `Provider` instance may be created and passed during resource
        construction to achieve fine-grained programmatic control over provider settings. See the
        [documentation](https://www.pulumi.com/docs/reference/programming-model/#providers) for more information.

        :param str resource_name: The name of the resource.
        :param ProviderArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(ProviderArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 kong_admin_password: Optional[pulumi.Input[builtins.str]] = None,
                 kong_admin_token: Optional[pulumi.Input[builtins.str]] = None,
                 kong_admin_uri: Optional[pulumi.Input[builtins.str]] = None,
                 kong_admin_username: Optional[pulumi.Input[builtins.str]] = None,
                 kong_api_key: Optional[pulumi.Input[builtins.str]] = None,
                 kong_workspace: Optional[pulumi.Input[builtins.str]] = None,
                 strict_plugins_match: Optional[pulumi.Input[builtins.bool]] = None,
                 tls_skip_verify: Optional[pulumi.Input[builtins.bool]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = ProviderArgs.__new__(ProviderArgs)

            __props__.__dict__["kong_admin_password"] = kong_admin_password
            __props__.__dict__["kong_admin_token"] = kong_admin_token
            __props__.__dict__["kong_admin_uri"] = kong_admin_uri
            __props__.__dict__["kong_admin_username"] = kong_admin_username
            __props__.__dict__["kong_api_key"] = kong_api_key
            __props__.__dict__["kong_workspace"] = kong_workspace
            if strict_plugins_match is None:
                strict_plugins_match = _utilities.get_env_bool('STRICT_PLUGINS_MATCH')
            __props__.__dict__["strict_plugins_match"] = pulumi.Output.from_input(strict_plugins_match).apply(pulumi.runtime.to_json) if strict_plugins_match is not None else None
            if tls_skip_verify is None:
                tls_skip_verify = (_utilities.get_env_bool('TLS_SKIP_VERIFY') or False)
            __props__.__dict__["tls_skip_verify"] = pulumi.Output.from_input(tls_skip_verify).apply(pulumi.runtime.to_json) if tls_skip_verify is not None else None
        super(Provider, __self__).__init__(
            'kong',
            resource_name,
            __props__,
            opts)

    @property
    @pulumi.getter(name="kongAdminPassword")
    def kong_admin_password(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        An basic auth password for kong admin
        """
        return pulumi.get(self, "kong_admin_password")

    @property
    @pulumi.getter(name="kongAdminToken")
    def kong_admin_token(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        API key for the kong api (Enterprise Edition)
        """
        return pulumi.get(self, "kong_admin_token")

    @property
    @pulumi.getter(name="kongAdminUri")
    def kong_admin_uri(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        The address of the kong admin url e.g. http://localhost:8001
        """
        return pulumi.get(self, "kong_admin_uri")

    @property
    @pulumi.getter(name="kongAdminUsername")
    def kong_admin_username(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        An basic auth user for kong admin
        """
        return pulumi.get(self, "kong_admin_username")

    @property
    @pulumi.getter(name="kongApiKey")
    def kong_api_key(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        API key for the kong api (if you have locked it down)
        """
        return pulumi.get(self, "kong_api_key")

    @property
    @pulumi.getter(name="kongWorkspace")
    def kong_workspace(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        Workspace context (Enterprise Edition)
        """
        return pulumi.get(self, "kong_workspace")

    @pulumi.output_type
    class TerraformConfigResult:
        def __init__(__self__, result=None):
            if result and not isinstance(result, dict):
                raise TypeError("Expected argument 'result' to be a dict")
            pulumi.set(__self__, "result", result)

        @property
        @pulumi.getter
        def result(self) -> Mapping[str, Any]:
            return pulumi.get(self, "result")

    def terraform_config(__self__) -> pulumi.Output['Provider.TerraformConfigResult']:
        """
        This function returns a Terraform config object with terraform-namecased keys,to be used with the Terraform Module Provider.
        """
        __args__ = dict()
        __args__['__self__'] = __self__
        return pulumi.runtime.call('pulumi:providers:kong/terraformConfig', __args__, res=__self__, typ=Provider.TerraformConfigResult)

